#
# spec file for package pgaudit
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#
%define         pg_libdir %(pg_config --pkglibdir)

# name_pg uses --keep-name-conditionals (argument of spec_query)
# loophole
%define         name_pg  postgresql11%{nil}
%define         sname    pgaudit

%if ("%{name_pg}" == "postgresql11" || "%{name_pg}" == "postgresql12") && 0%{?suse_version} >= 1500
%bcond_without  llvm
%else
%bcond_with     llvm
%endif

%if "%{name_pg}" == ""
# nill flavour
Name:           pgaudit
ExclusiveArch:  do_not_build
%else
Name:           %{name_pg}-pgaudit
%endif
%if "%{name_pg}" == "postgresql96"
Version:        1.1.4
%endif
%if "%{name_pg}" == "postgresql10"
Version:        1.2.3
%endif
%if "%{name_pg}" == "postgresql11"
Version:        1.3.3
%endif
%if "%{name_pg}" == "postgresql12"
Version:        1.4.2
%endif
Release:        lp152.8.1
Summary:        An auditing module for PostgreSQL
License:        PostgreSQL
Group:          Productivity/Databases/Tools
Url:            https://github.com/pgaudit/pgaudit
%if "%{name_pg}" != ""
# not nill flavour
Source:         %{sname}-%{version}.tar.gz
%endif
BuildRequires:  %{name_pg}-devel
BuildRequires:  %{name_pg}-server-devel
BuildRequires:  %{name_pg}-server
Requires:       %{name_pg}-server
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This is the initial version of an auditing module for Postgres.

It collects audit events from various sources and logs them in CSV format
including a timestamp, user information, details of objects affected (if any),
and the fully-qualified command text (whenever available).

All DDL, DML (including SELECT), and utility commands are supported. These
are categorised as described below, and audit logging for each group of
commands may be enabled or disabled by the superuser. Once enabled, however,
audit logging may not be disabled by a user.


%if %{with llvm}
%package llvmjit
Summary:        Just-in-time compilation support for PostgreSQL %{sname} extension
Group:          Productivity/Databases/Servers
Requires:       %{name_pg}-server
Requires:       %{name_pg}-llvmjit
Requires:       %{name_pg}-%{sname} = %{version}-%{release}
Supplements:    packageand(%{name_pg}-llvmjit:%{name})

%description llvmjit
This package contains support for just-in-time compiling parts of
PostgreSQL queries. Using LLVM it compiles e.g. expressions and tuple
deforming into native code, with the goal of accelerating analytics
queries.
%endif

%prep
%setup -q -n %{sname}-%{version}

%build
export PATH="$PATH:/usr/lib/%{name_pg}/bin"
make USE_PGXS=1 %{?_smp_mflags}

%install
export PATH="$PATH:/usr/lib/%{name_pg}/bin"
make USE_PGXS=1 install DESTDIR=%{buildroot}

%files
%defattr(-,root,root)
%doc README.md LICENSE sql/
%{_prefix}/lib/%{name_pg}/%{_lib}/%{sname}.so
%{_datadir}/%{name_pg}/extension/%{sname}*

%if %{with llvm}
%files llvmjit
%{pg_libdir}/bitcode/*
%endif

%changelog
* Tue Nov 16 2021 pgajdos@suse.com
- version update [bsc#1192709]
  - 1.1.4: https://github.com/pgaudit/pgaudit/releases/tag/1.1.4
  - 1.2.3: https://github.com/pgaudit/pgaudit/releases/tag/1.2.3
  - 1.3.3: https://github.com/pgaudit/pgaudit/releases/tag/1.3.3
  - 1.4.2: https://github.com/pgaudit/pgaudit/releases/tag/1.4.2
* Wed Nov  4 2020 pgajdos@suse.com
- try to make factory bot happy
* Tue Nov  3 2020 pgajdos@suse.com
- revert last change, keep flavours unresolved
* Wed Oct 21 2020 pgajdos@suse.com
- do not build favours that would be unresolved in standard repos
* Tue Oct 20 2020 pgajdos@suse.com
- version update
  - 1.0.8: https://github.com/pgaudit/pgaudit/releases/tag/1.0.8
  - 1.1.3: https://github.com/pgaudit/pgaudit/releases/tag/1.1.3
  - 1.2.2: https://github.com/pgaudit/pgaudit/releases/tag/1.2.2
  - 1.3.3: https://github.com/pgaudit/pgaudit/releases/tag/1.3.2
  - 1.4.1: https://github.com/pgaudit/pgaudit/releases/tag/1.4.1
* Fri Sep 25 2020 Marcus Rueckert <mrueckert@suse.de>
- added pg 13 support by adding 1.5.0
  https://github.com/pgaudit/pgaudit/releases/tag/1.5.0
* Wed May  6 2020 Marcus Rueckert <mrueckert@suse.de>
- we added support for newer pg versions but never enabled them in
  the multibuild
* Tue Oct 22 2019 Marcus Rueckert <mrueckert@suse.de>
- bump package for existing versions and add support for newer pg
  versions:
  - 1.0.7: https://github.com/pgaudit/pgaudit/releases/tag/1.0.7
  - 1.1.2: https://github.com/pgaudit/pgaudit/releases/tag/1.1.2
  - 1.2.1: https://github.com/pgaudit/pgaudit/releases/tag/1.2.1
  - 1.3.1: https://github.com/pgaudit/pgaudit/releases/tag/1.3.1
  - 1.4.0: https://github.com/pgaudit/pgaudit/releases/tag/1.4.0
* Fri Sep  8 2017 mrueckert@suse.de
- make the file lists less broad:
  - BR the -server package so we get the owner of
    %%{_datadir}/postgresql*/extension/
  - only own files really from this package
* Fri Aug  4 2017 mrueckert@suse.de
- use multibuild
- update to 1.0.6 and 1.1.1 respectively
* Thu Feb 19 2015 mrueckert@suse.de
- update to git HEAD: (adds HEAD.patch)
  - 9bdc2e8 Use bms_{copy,first_member,free} on
    rte->{selected,modified}Cols
  - 869f4e7 Take column-level privileges into account too
  - 715b653 If audit has been granted permissions, we log the event
  - 7d9313c Make should_be_logged() authoritative by itself
  - 58aa1f4 Describe the current behaviour more precisely
  - 43f9baf If no roles are given, all roles are audited
  - c0b4e6d Add pgaudit.roles setting
  - fe5219f Rename T_AlterTableSpaceMoveStmt to
    T_AlterTableMoveAllStmt following 3c4cf08
  - 98eb0ed We don't need the [] wrapper
  - ab43873 Remove GUC source checking altogether
  - 7782701 Fixes for META.json
* Tue Oct  7 2014 darin@darins.net
- fixed %%files path for SLES
* Mon Oct  6 2014 darin.perusich@ctg.com
- Initial packaging of pgaudit
